@@ -1113,6 +1113,156 @@ class ZbxCommon(object):
     def get_mysql_current_database(self, conn):
         return self.mysql_query(conn, "select database()")[0]['database()']
 
+    def load_csv_from_file(self, file_name):
+        import csv
+        data = []
+        with open(file_name, 'r') as f:
+            reader = csv.reader(f)
+            for row in reader:
+                data.append(row)
+        return data
+
+    def load_csv_from_string(self, csv_string):
+        import csv
+        data = []
+        reader = csv.reader(csv_string.splitlines())
+        for row in reader:
+            data.append(row)
+        return data
+
+    def load_csv2json(self, file_name='', data=''):
+        if data != '':
+            data = self.load_csv_from_string(data)
+        else:
+            data = self.load_csv_from_file(file_name)
+        if len(data) > 0:
+            fields = data[0]
+            data2 = []
+            for row in data[1:]:
+                data2.append(dict(zip(fields, row)))
+            return data2
+        return []
+
+    def excel2csv(self, filename, date_format='%Y-%m-%d %H:%M:%S'):
+        import xlrd
+        import csv
+        import io
+        import re
+        intreg = re.compile(r'^\d\.0{1,}$')
+        wb = xlrd.open_workbook(filename)
+        sh = wb.sheet_by_index(0)
+        buffer = io.StringIO()
+        wr = csv.writer(buffer, quoting=csv.QUOTE_ALL)
+        for rownum in range(sh.nrows):
+            cols = sh.row(rownum)
+            vals = []
+            for col in cols:
+                val = col.value
+                if col.ctype == xlrd.XL_CELL_DATE:
+                    col.value = xlrd.xldate.xldate_as_datetime(col.value, 0)
+                    val = col.value.strftime(date_format)
+                elif col.ctype == xlrd.XL_CELL_NUMBER:
+                    if intreg.match(str(val)):
+                        val = int(val)
+                vals.append(val)
+            wr.writerow(vals)
+        return buffer.getvalue()
+
+    def dump_excel(self, data, file_name='data.xls', date_format='%Y-%m-%d %H:%M:%S'):
+        from openpyxl import Workbook
+        wb = Workbook()
+        ws = wb.active
+        if isinstance(data, str):
+            data = json.loads(data)
+        if isinstance(data, dict):
+            data = [data]
+        if isinstance(data, list):
+            rows = data
+            results = []
+            keys = []
+            if len(rows) > 0:
+                keys = rows[0].keys()
+                # results.append(','.join(keys))
+                ws.append(list(keys))
+                for row in rows:
+                    result = []
+                    for k in keys:
+                        v = row.get(k)
+                        if v is None:
+                            v = ''
+                        if isinstance(v, datetime.datetime):
+                            v = v.strftime(date_format)
+                        if isinstance(v, int) and len(str(v)) == 10:
+                            v = datetime.datetime.fromtimestamp(v).strftime(date_format)
+
+                        # if isinstance(v, str):
+                        #     v = v.replace('"', '\"')
+                        result.append(v)
+                    ws.append(result)
+                    # results.append(','.join(result))
+        if file_name != '':
+            wb.save(file_name)
+            wb.close()
+
+    def _convert_to_list(self, data):
+        if isinstance(data, str):
+            data = json.loads(data)
+        if isinstance(data, dict):
+            data = [data]
+        return data
+
+    def dump_csv_string(self, data, date_format='%Y-%m-%d %H:%M:%S'):
+        if isinstance(data, str):
+            data = json.loads(data)
+        if isinstance(data, dict):
+            data = [data]
+        if isinstance(data, list):
+            rows = data
+            results = []
+            keys = []
+            if len(rows) > 0:
+                keys = rows[0].keys()
+                results.append(','.join(keys))
+                for row in rows:
+                    result = []
+                    for k in keys:
+                        v = row.get(k)
+                        if v is None:
+                            v = ''
+                        if isinstance(v, str):
+                            if re.findall(r'[\r\n,"]+', v):
+                                v = v.replace('"', '""')
+                                v = '"%s"' % v
+                        if isinstance(v, datetime.datetime):
+                            v = v.strftime(date_format)
+                        if isinstance(v, int) and len(str(v)) == 10:
+                            v = datetime.datetime.fromtimestamp(v).strftime(date_format)
+                        result.append(str(v))
+                    results.append(','.join(result))
+        return "\n".join(results)
+
+    def dump_csv(self, data, file_name='data.csv', date_format='%Y-%m-%d %H:%M:%S'):
+        with open(file_name, "w") as fp:
+            fp.write(self.dump_csv_string(data, date_format))
+        # import csv
+        # with open(file_name,'w') as fp:
+        #     writer=csv.writer(fp)
+        #     rows=self._convert_to_list(data)
+        #     if len(rows) > 0:
+        #         keys = rows[0].keys()
+        #         keys=list(keys)
+        #         writer.writerow(keys)
+        #         for row in rows:
+        #             result = []
+        #             for k in keys:
+        #                 v = row.get(k)
+        #                 if isinstance(v, datetime.datetime):
+        #                     v = v.strftime(date_format)
+        #                 if isinstance(v, int) and len(str(v)) == 10:
+        #                     v = datetime.datetime.fromtimestamp(v).strftime(date_format)
+        #                 result.append(v)
+        #             writer.writerow(result)
+
     def dump_sqlite_ddl(self, conn, dir='', tables=[]):
         tables_info = []
         infos = []
